| Title: | An RKWard plugin suite for conditional recoding, case_when logic, and fixing mixed dates using dplyr, janitor, and lubridate. |
|---|---|
| Description: | An RKWard plugin suite for conditional recoding, case_when logic, and fixing mixed dates using dplyr, janitor, and lubridate. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.1 |
| Built: | 2026-07-14 03:14:37 UTC |
| Source: | https://github.com/AlfCano/rk.case.if |